import axios from 'axios';

export default {
	name: 'FormMixin',
	data() {
		return {
			interceptor: null,
			formsLoading: [],
			clickLoading: false,
			showNewForm: false,
		}
	},
	mounted() {
		this.interceptor = axios.interceptors.response.use((res) => {
			this.formsLoading = [];
			this.clickLoading = false;
			return res;
		}, (error) => {
			this.formsLoading = [];
			this.clickLoading = false;
			return Promise.reject(error);
		});
	},
	destroyed() {
		axios.interceptors.request.eject(this.interceptor);
	},
	computed: {
		formLoading() {
			return (form) => {
				return this.formsLoading.includes(form);
			}
		},
	},
	methods: {
		submitForm(validate, callback, data = null) {
			validate().then((valid) => {
				if (valid) {
					this.formsLoading.push(callback);
					this[callback](data);
				}
			});
		},
		getPondFiles(image) {
			if (image) {
				return [{
					source: image,
					options: {type: 'local'}
				}];
			}
			return [];
		},
		getPondServer(url, process, remove) {
			let requestHeaders = {
				'Accept': 'application/json',
				'Authorization': token,
			};
			return {
				url: url,
				process: {
					headers: requestHeaders,
					onload: process
				},
				revert: {
					headers: requestHeaders
				},
				load: { headers: requestHeaders },
				remove: (source, load, error) => {
					Api.delete(url, { load: source }, (path) => {
						remove();
						load();
					});
				}
			};
		}
	},
	watch: {
		showNewForm: function(newValue, oldValue) {
			if (newValue) {
				this.$nextTick(() => {
					const autofocus = this.$refs.autofocus;
					if (autofocus) {
						setTimeout(() => {
							autofocus.focus();
						}, 1);
					}
				});
			}
		}
	},
};
